@@ -1449,8 +1449,16 @@ class CroniterTest(base.TestCase):
         nextnow2 = croniter('* * * * * ', now).next(datetime)
         for nt in nextnow, nextnow2:
             self.assertEqual(nt.tzinfo.zone, 'America/New_York')
-            self.assertEqual(int(nt.timestamp()), 1547481660)
+            self.assertEqual(int(croniter._datetime_to_timestamp(nt)), 1547481660)
 
+    def test_issue_k12(self):
+        tz = pytz.timezone('Europe/Athens')
+        base = datetime(2010, 1, 23, 12, 18, tzinfo=tz)
+        itr = croniter('* * * * *')
+        itr.set_current(start_time=base)
+        n1 = itr.get_next()   # 19
+
+        self.assertEqual(n1, base.timestamp() + 60)
 
 if __name__ == '__main__':
     unittest.main()
